@@ -1,5 +1,5 @@
 
-#       Copyright (C) 2008-2017 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -16,4 +16,4 @@
 #
 #       Author:  Vicent Mas - vmas@vitables.org
 
-__all__ = ['csv', 'columnorg', 'dbstreesort', 'timeseries']
+__all__ = ['columnorg', 'dbstreesort', 'timeseries']
