@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2017 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -87,27 +87,32 @@ setting into the config file.
 
 """
 
-__docformat__ = 'restructuredtext'
-__version__ = '3.0.0'
-
-import sys
 import logging
+import sys
+from vitables.preferences import cfgexception
+import vitables.utils
 
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
 
-from vitables.preferences import cfgexception
-import vitables.utils
 import vitables.vttables.datasheet as datasheet
 
+
+__docformat__ = 'restructuredtext'
+__version__ = '3.0.2'
+
 translate = QtWidgets.QApplication.translate
 
+
 def getVersion():
     """The application version."""
     return __version__
 
 
+log = logging.getLogger(__name__)
+
+
 class Config(QtCore.QSettings):
     """
     Manages the application configuration dynamically.
@@ -132,19 +137,24 @@ class Config(QtCore.QSettings):
         is UserScope.
         """
 
-        self.logger = logging.getLogger(__name__)
-        self.logger.setLevel(logging.INFO)
-
         organization = QtWidgets.qApp.organizationName()
         product = QtWidgets.qApp.applicationName()
         version = QtWidgets.qApp.applicationVersion()
         if sys.platform.startswith('win'):
-            path = 'HKEY_CURRENT_USER\\Software\\{0}\\{1}'
-            rpath = path.format(product, version)
-            super(Config, self).__init__(rpath, QtCore.QSettings.NativeFormat)
+            # organizationName() -> product
+            # applicationName() -> version
+            super(Config, self).__init__(product, version)
+            self.reg_path = 'HKEY_CURRENT_USER\\Software\\{0}\\{1}'.format(
+                product, version)
+            self.setPath(QtCore.QSettings.NativeFormat,
+                         QtCore.QSettings.UserScope, self.reg_path)
         elif sys.platform.startswith('darwin'):
+            # organizationName() -> product
+            # applicationName() -> version
             super(Config, self).__init__(product, version)
         else:
+            # organizationName() -> organization
+            # applicationName() -> product-version
             arg1 = organization
             arg2 = '-'.join((product, version))
             super(Config, self).__init__(arg1, arg2)
@@ -164,7 +174,6 @@ class Config(QtCore.QSettings):
                     self.default_style = item
                     break
 
-
     def loggerPaper(self):
         """
         Returns the logger background color.
@@ -178,7 +187,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def loggerText(self):
         """
         Returns the logger text color.
@@ -192,7 +200,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def loggerFont(self):
         """
         Returns the logger font.
@@ -206,7 +213,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def workspaceBackground(self):
         """
         Returns the workspace background color.
@@ -220,7 +226,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def readStyle(self):
         """Returns the current application style."""
 
@@ -240,10 +245,14 @@ class Config(QtCore.QSettings):
         else:
             return setting_value
 
-
     def windowPosition(self):
         """
-        Returns the main window geometry setting.
+        Returns the main window geometry settings.
+
+        Basically the main window geometry is made of the x and y coordinates
+        of the top left corner, width and height. A QByteArray with all this
+        information can be created via QMainWindow.saveGeometry() and stored
+        in a setting with QSetting.setValue()
         """
 
         key = 'Geometry/Position'
@@ -254,7 +263,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def windowLayout(self):
         """
         Returns the main window layout setting.
@@ -271,7 +279,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def hsplitterPosition(self):
         """
         Returns the horizontal splitter geometry setting.
@@ -285,12 +292,15 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-    def startupLastSession(self):
+    def restoreLastSession(self):
         """
         Returns the `Restore last session` setting.
+
+        This is a user preference that can be setup in the Preferences dialog,
+        with the 'Restore last session' checkbox.
         """
 
-        key = 'Startup/restoreLastSession'
+        key = 'Session/restoreLastSession'
         default_value = False
         # Warning!
         # If the application settings have not yet been saved
@@ -307,36 +317,44 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
-    #TODO: remove this setting
     def startupWorkingDir(self):
         """
         Returns the `Startup working directory` setting.
+
+        The startup working directory is the directory to be accessed the very
+        first time a file opening happens in a working session. The setting can
+        have two values:
+        - last -> go to the last directory accessed in the previous ViTables
+            session
+        - current -> go to the current working directory if ViTables started
+            from a terminal and go to the home directory otherwise
+
+        This is a user preference that can be setup in the Preferences dialog,
+        with the 'Start in last working directory' checkbox.
         """
 
-        key = 'Startup/startupWorkingDir'
+        key = 'Session/startupWorkingDir'
         default_value = 'home'
         setting_value = self.value(key)
-        if isinstance(setting_value, str):
+        if setting_value in ['last', 'current']:
             return setting_value
         else:
             return default_value
 
-
     def lastWorkingDir(self):
         """
         Returns the `Last working directory` setting.
         """
 
-        key = 'Startup/lastWorkingDir'
+        key = 'Session/lastWorkingDir'
         default_value = vitables.utils.getHomeDir()
         setting_value = self.value(key)
         if isinstance(setting_value, str):
+            # TODO: check if the value is an existing file
             return setting_value
         else:
             return default_value
 
-
     def recentFiles(self):
         """
         Returns the list of most recently opened files setting.
@@ -350,7 +368,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def sessionFiles(self):
         """
         Returns the list of files and nodes opened when the last session quit.
@@ -364,7 +381,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def helpHistory(self):
         """
         Returns the navigation history of the docs browser.
@@ -378,7 +394,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def helpBookmarks(self):
         """
         Returns the bookmarks of the docs browser.
@@ -392,7 +407,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def enabledPlugins(self):
         """Returns the list of enabled plugins.
         """
@@ -405,7 +419,6 @@ class Config(QtCore.QSettings):
         else:
             return default_value
 
-
     def writeValue(self, key, value):
         """
         Write an entry to the configuration file.
@@ -422,7 +435,7 @@ class Config(QtCore.QSettings):
                 raise cfgexception.ConfigFileIOException(
                     '{0}={1}'.format(key, value))
         except cfgexception.ConfigFileIOException as inst:
-            self.logger.error(inst.error_message)
+            log.error(inst.error_message)
 
     def readConfiguration(self):
         """
@@ -443,9 +456,9 @@ class Config(QtCore.QSettings):
         config['Logger/Text'] = self.loggerText()
         config['Logger/Font'] = self.loggerFont()
         config['Workspace/Background'] = self.workspaceBackground()
-        config['Startup/restoreLastSession'] = self.startupLastSession()
-        config['Startup/startupWorkingDir'] = self.startupWorkingDir()
-        config['Startup/lastWorkingDir'] = self.lastWorkingDir()
+        config['Session/restoreLastSession'] = self.restoreLastSession()
+        config['Session/startupWorkingDir'] = self.startupWorkingDir()
+        config['Session/lastWorkingDir'] = self.lastWorkingDir()
         config['Geometry/Position'] = self.windowPosition()
         config['Geometry/Layout'] = self.windowLayout()
         config['Geometry/HSplitter'] = self.hsplitterPosition()
@@ -457,96 +470,7 @@ class Config(QtCore.QSettings):
         config['Plugins/Enabled'] = self.enabledPlugins()
         return config
 
-
-    def saveConfiguration(self):
-        """
-        Store current application settings on disk.
-
-        Note that we are using ``QSettings`` for writing to the config file,
-        so we **must** rely on its searching algorithms in order to find
-        that file.
-        """
-
-        vtgui = self.vtapp.gui
-        # Logger paper
-        style_sheet = vtgui.logger.styleSheet()
-        paper = style_sheet[-7:]
-        self.writeValue('Logger/Paper', QtGui.QColor(paper))
-        # Logger text color
-        self.writeValue('Logger/Text', vtgui.logger.textColor())
-        # Logger text font
-        self.writeValue('Logger/Font', vtgui.logger.font())
-        # Workspace
-        self.writeValue('Workspace/Background', vtgui.workspace.background())
-        # Style
-        self.writeValue('Look/currentStyle', self.current_style)
-        # Startup working directory
-        self.writeValue('Startup/startupWorkingDir',
-            self.startup_working_directory)
-        # Startup restore last session
-        self.writeValue('Startup/restoreLastSession',
-            self.restore_last_session)
-        # Startup last working directory
-        self.writeValue('Startup/lastWorkingDir', self.last_working_directory)
-        # Window geometry
-        self.writeValue('Geometry/Position', vtgui.saveGeometry())
-        # Window layout
-        self.writeValue('Geometry/Layout', vtgui.saveState())
-        # Horizontal splitter geometry
-        self.writeValue('Geometry/HSplitter', vtgui.hsplitter.saveState())
-        # The list of recent files
-        self.writeValue('Recent/Files', self.recent_files)
-        # The list of session files and nodes
-        self.session_files_nodes = self.getSessionFilesNodes()
-        self.writeValue('Session/Files', self.session_files_nodes)
-        # The Help Browser history
-        self.writeValue('HelpBrowser/History', self.hb_history)
-        # The Help Browser bookmarks
-        self.writeValue('HelpBrowser/Bookmarks', self.hb_bookmarks)
-        # The list of enabled plugins
-        self.writeValue('Plugins/Enabled',
-                        self.vtapp.plugins_mgr.enabled_plugins)
-        self.sync()
-
-
-    def getSessionFilesNodes(self):
-        """
-        The list of files and nodes currently open.
-
-        The list looks like::
-
-            ['mode#@#filepath1#@#nodepath1#@#nodepath2, ...',
-            'mode#@#filepath2#@#nodepath1#@#nodepath2, ...', ...]
-        """
-
-        # Get the list of views
-        workspace = self.vtapp.gui.workspace
-        node_views = [window for window in workspace.subWindowList() \
-                        if isinstance(window, datasheet.DataSheet)]
-
-        # Get the list of open files (temporary database is not included)
-        dbt_model = self.vtapp.gui.dbs_tree_model
-        session_files_nodes = []
-        filepaths = dbt_model.getDBList()
-
-        for path in filepaths:
-            mode = dbt_model.getDBDoc(path).mode
-            # If a new file has been created during the current session
-            # then write mode must be replaced by append mode or the file
-            # will be created from scratch in the next ViTables session
-            if mode == 'w':
-                mode = 'a'
-            item_path = mode + '#@#' + path
-            for view in node_views:
-                if view.dbt_leaf.filepath == path:
-                    item_path = item_path + '#@#' + view.dbt_leaf.nodepath
-            session_files_nodes.append(item_path)
-
-        # Format the list in a handy way to store it on disk
-        return session_files_nodes
-
-
-    def loadConfiguration(self, config):
+    def applyConfiguration(self, config):
         """
         Configure the application with the given settings.
 
@@ -560,7 +484,7 @@ class Config(QtCore.QSettings):
         """
 
         # Load the user settings
-        self.userSettings(config)
+        self.applyUserPreferences(config)
 
         # Load the internal settings (if any)
         gui = self.vtapp.gui
@@ -583,7 +507,7 @@ class Config(QtCore.QSettings):
                 # Default geometry provided by the underlying Qt installation
                 gui.hsplitter.restoreState(value)
 
-            key = 'Startup/lastWorkingDir'
+            key = 'Session/lastWorkingDir'
             self.last_working_directory = config[key]
 
             key = 'Recent/Files'
@@ -600,9 +524,8 @@ class Config(QtCore.QSettings):
         except KeyError:
             pass
 
-
-    def userSettings(self, config):
-        """Load settings that can be setup via Settings dialog.
+    def applyUserPreferences(self, config):
+        """Apply settings that can be setup via Settings dialog.
 
         :Parameter config: a dictionary with the settings to be (re)loaded
         """
@@ -610,13 +533,13 @@ class Config(QtCore.QSettings):
         # Usually after calling the Settings dialog only some user
         # settings will need to be reloaded. So for every user setting
         # we have to check if it needs to be reloaded or not
-        key = 'Startup/restoreLastSession'
+        key = 'Session/restoreLastSession'
         if key in config:
             self.restore_last_session = config[key]
 
-        key = 'Startup/startupWorkingDir'
+        key = 'Session/startupWorkingDir'
         if key in config:
-            self.startup_working_directory = config[key]
+            self.initial_working_directory = config[key]
 
         key = 'Logger/Paper'
         logger = self.vtapp.gui.logger
@@ -652,3 +575,89 @@ class Config(QtCore.QSettings):
         key = 'Plugins/Enabled'
         if key in config:
             self.enabled_plugins = config[key]
+
+    def saveConfiguration(self):
+        """
+        Store current application settings on disk.
+
+        Note that we are using ``QSettings`` for writing to the config file,
+        so we **must** rely on its searching algorithms in order to find
+        that file.
+        """
+
+        vtgui = self.vtapp.gui
+        # Logger paper
+        style_sheet = vtgui.logger.styleSheet()
+        paper = style_sheet[-7:]
+        self.writeValue('Logger/Paper', QtGui.QColor(paper))
+        # Logger text color
+        self.writeValue('Logger/Text', vtgui.logger.textColor())
+        # Logger text font
+        self.writeValue('Logger/Font', vtgui.logger.font())
+        # Workspace
+        self.writeValue('Workspace/Background', vtgui.workspace.background())
+        # Style
+        self.writeValue('Look/currentStyle', self.current_style)
+        # Startup working directory
+        self.writeValue('Session/startupWorkingDir',
+                        self.initial_working_directory)
+        # Startup restore last session
+        self.writeValue('Session/restoreLastSession',
+                        self.restore_last_session)
+        # Startup last working directory
+        self.writeValue('Session/lastWorkingDir', self.last_working_directory)
+        # Window geometry
+        self.writeValue('Geometry/Position', vtgui.saveGeometry())
+        # Window layout
+        self.writeValue('Geometry/Layout', vtgui.saveState())
+        # Horizontal splitter geometry
+        self.writeValue('Geometry/HSplitter', vtgui.hsplitter.saveState())
+        # The list of recent files
+        self.writeValue('Recent/Files', self.recent_files)
+        # The list of session files and nodes
+        self.session_files_nodes = self.getSessionFilesNodes()
+        self.writeValue('Session/Files', self.session_files_nodes)
+        # The Help Browser history
+        self.writeValue('HelpBrowser/History', self.hb_history)
+        # The Help Browser bookmarks
+        self.writeValue('HelpBrowser/Bookmarks', self.hb_bookmarks)
+        # The list of enabled plugins
+        self.writeValue('Plugins/Enabled',
+                        self.vtapp.plugins_mgr.enabled_plugins)
+        self.sync()
+
+    def getSessionFilesNodes(self):
+        """
+        The list of files and nodes currently open.
+
+        The list looks like::
+
+            ['mode#@#filepath1#@#nodepath1#@#nodepath2, ...',
+            'mode#@#filepath2#@#nodepath1#@#nodepath2, ...', ...]
+        """
+
+        # Get the list of views
+        workspace = self.vtapp.gui.workspace
+        node_views = [window for window in workspace.subWindowList()
+                      if isinstance(window, datasheet.DataSheet)]
+
+        # Get the list of open files (temporary database is not included)
+        dbt_model = self.vtapp.gui.dbs_tree_model
+        session_files_nodes = []
+        filepaths = dbt_model.getDBList()
+
+        for path in filepaths:
+            mode = dbt_model.getDBDoc(path).mode
+            # If a new file has been created during the current session
+            # then write mode must be replaced by append mode or the file
+            # will be created from scratch in the next ViTables session
+            if mode == 'w':
+                mode = 'a'
+            item_path = mode + '#@#' + path
+            for view in node_views:
+                if view.dbt_leaf.filepath == path:
+                    item_path = item_path + '#@#' + view.dbt_leaf.nodepath
+            session_files_nodes.append(item_path)
+
+        # Format the list in a handy way to store it on disk
+        return session_files_nodes
