@@ -1,5 +1,5 @@
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2017 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -15,15 +15,12 @@
 #       along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 #       Author:  Vicent Mas - vmas@vitables.org
-from qtpy.QtWidgets import QFileDialog
 
 """
 This is the utilities module. It contains functions that perform
 tasks that are required at several parts of the application.
 """
 
-__docformat__ = 'restructuredtext'
-
 import sys
 import os
 import traceback
@@ -34,18 +31,22 @@ import collections
 import functools
 
 import numpy
+import tables
 
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
+from qtpy.QtWidgets import QFileDialog
 
 import vitables.vtwidgets.renamedlg as renamedlg
-from vitables.vtsite import ICONDIR, DOCDIR
+from vitables.vtsite import ICONDIR
 
+__docformat__ = 'restructuredtext'
 
 ICONS_DICT = {}
 HB_ICONS_DICT = {}
 DEFAULT_ENCODING = locale.getdefaultlocale()[1]
+log = logging.getLogger(__name__)
 
 
 def getVTApp():
@@ -133,27 +134,6 @@ def long_action(message=None):
     return _long_action
 
 
-def addToMenuBar(menu, enable_function=None):
-    """Add menu to the menu bar into one before last position.
-
-    Basically insert a menu before Help menu. Actions can be enabled
-    or disabled by enable_function which is connected to aboutToShow
-    signal of the submenu.
-
-    :parameter menu: QMenu object
-    :parameter enable_function: is connected to aboutToShow for menu
-
-    :return: None
-
-    """
-
-    menu_bar = getGui().menuBar()
-    last_action = menu_bar.actions()[-1]
-    menu_bar.insertMenu(last_action, menu)
-    if enable_function is not None:
-        menu.aboutToShow.connect(enable_function)
-
-
 def insertInMenu(menu, entries, uid):
     """Insert entries to the given menu before the action named uid.
 
@@ -180,7 +160,7 @@ def insertInMenu(menu, entries, uid):
     for item in menu.actions():
         if item.objectName() == uid:
             for a in entries:
-                menu.insertEntry(item, a)
+                qa = menu.insertEntry(item, a)
 
 
 def addToMenu(menu, entries):
@@ -210,6 +190,31 @@ def addToMenu(menu, entries):
         menu.addEntry(a)
 
 
+def addActions(target, actions, actions_dict):
+    """Add a list of QActions to a menu or a toolbar.
+
+    This is a helper function which make easier to add QActions to a
+    menu or a toolbar. Separators and submenus are also handled by this
+    method.
+
+    :Parameters:
+
+    - `target`: the menu or toolbar where actions will be added
+    - `actions`: a sequence of keywords/None/QMenu used to get actions
+                 from a mapping
+    - `actions_dict`: a mapping of actions
+
+    """
+
+    for action in actions:
+        if action is None:
+            target.addSeparator()
+        elif isinstance(action, QtWidgets.QMenu):
+            target.addMenu(action)
+        else:
+            target.addAction(actions_dict[action])
+
+
 def addToLeafContextMenu(actions, enable_function=None):
     """Add entries at the end of the leaf context menu.
 
@@ -277,7 +282,7 @@ def getFileSelector(parent, caption, dfilter, filepath='', settings=None):
     # comes at the price of an annoying KDE warning in your console. See the
     # thread "A dire warning message" (July, 2011) in the pyQt4 mailing list
     # for details.
-    #file_selector.setOption(QtWidgets.QFileDialog.DontUseNativeDialog)
+    # file_selector.setOption(QtWidgets.QFileDialog.DontUseNativeDialog)
     return file_selector
 
 
@@ -335,6 +340,7 @@ def checkFileExtension(filepath):
 # Icons related functions
 #
 
+
 def createIcons(large_icons, small_icons, icons_dict):
     """
     Create icons for different components of the GUI.
@@ -361,7 +367,7 @@ def createIcons(large_icons, small_icons, icons_dict):
             icon.addPixmap(pixmap, QtGui.QIcon.Normal, QtGui.QIcon.On)
         if name in small_icons:
             pixmap = QtGui.QPixmap(
-                os.path.join(ICONDIR,'16x16', '{0}.png').format(name))
+                os.path.join(ICONDIR, '16x16', '{0}.png').format(name))
             icon.addPixmap(pixmap, QtGui.QIcon.Normal, QtGui.QIcon.On)
         icons_dict[name] = icon
 
@@ -381,7 +387,7 @@ def getIcons():
             # Icons for toolbars
             'document-close', 'document-new', 'document-open',
             'document-save-as', 'application-exit', 'folder-new',
-            'edit-copy', 'edit-cut', 'edit-delete','edit-paste',
+            'edit-copy', 'edit-cut', 'edit-delete', 'edit-paste',
             'help-contents',
             'view-filter', 'delete_filters',
             # Icons for tree pane items
@@ -391,8 +397,9 @@ def getIcons():
         small_icons = frozenset([
             # Icons for menu items
             'document-close', 'document-new', 'document-open',
-            'document-save-as', 'document-open-recent', 'application-exit',
-            'edit-cut', 'edit-copy','edit-delete','edit-paste',
+            'document-save-as', 'document-open-recent',
+            'document-export', 'document-import', 'application-exit',
+            'edit-cut', 'edit-copy', 'edit-delete', 'edit-paste',
             'edit-rename',
             'folder-new',
             'view-filter', 'delete_filters',
@@ -401,8 +408,8 @@ def getIcons():
             # Icons for tree pane items
             'image-missing', 'object', 'vlstring',
             'array', 'link_array', 'carray', 'link_carray',
-            'earray', 'link_earray', 'vlarray','link_vlarray',
-            'table', 'link_table',
+            'earray', 'link_earray', 'vlarray', 'link_vlarray',
+            'table', 'link_table', 'filenode',
             # Icons for node views
             'zoom-in',
             # Icons for buttons
@@ -418,49 +425,25 @@ def getHBIcons():
 
     if not HB_ICONS_DICT:
         large_icons = frozenset([
-        # Icons for toolbar
-        'go-first-view', 'go-previous-view', 'go-next-view', 'view-refresh',
-        'bookmarks', 'bookmark_add', 'zoom-in', 'zoom-out',
-        'edit-clear-history'])
+            # Icons for toolbar
+            'go-first-view', 'go-previous-view', 'go-next-view',
+            'view-refresh', 'bookmarks', 'bookmark_add', 'zoom-in', 'zoom-out',
+            'edit-clear-history'])
 
         small_icons = frozenset([
-        # Icons for menu items
-        'document-open', 'application-exit',
-        'zoom-in', 'zoom-out',
-        'go-first-view', 'go-previous-view', 'go-next-view', 'view-refresh',
-        'bookmarks', 'bookmark_add',
-        # Icons for buttons
-        'dialog-ok', 'dialog-cancel', 'list-remove'])
+            # Icons for menu items
+            'document-open', 'application-exit',
+            'zoom-in', 'zoom-out',
+            'go-first-view', 'go-previous-view', 'go-next-view',
+            'view-refresh',  'bookmarks', 'bookmark_add',
+            # Icons for buttons
+            'dialog-ok', 'dialog-cancel', 'list-remove'])
 
         createIcons(large_icons, small_icons, HB_ICONS_DICT)
 
     return HB_ICONS_DICT
 
 
-def addActions(target, actions, actions_dict):
-    """Add a list of QActions to a menu or a toolbar.
-
-    This is a helper function which make easier to add QActions to a
-    menu or a toolbar. Separators and submenus are also handled by this
-    method.
-
-    :Parameters:
-
-    - `target`: the menu or toolbar where actions will be added
-    - `actions`: a sequence of keywords used to get actions from a mapping
-    - `actions_dict`: a mapping of actions
-
-    """
-
-    for action in actions:
-        if action is None:
-            target.addSeparator()
-        elif isinstance(action, QtWidgets.QMenu):
-            target.addMenu(action)
-        else:
-            target.addAction(actions_dict[action])
-
-
 def formatArrayContent(content):
     """
     Nicely format the contents of a view (table widget) cell.
@@ -517,8 +500,7 @@ def formatStringContent(content):
             fcontent = content.decode(encoding=DEFAULT_ENCODING)
             return fcontent
         except UnicodeDecodeError:
-            logger = logging.getLogger(__name__)
-            logger.error('UnicodeDecodeError exception')
+            log.error('UnicodeDecodeError exception')
     return content
 
 
@@ -531,8 +513,7 @@ def formatExceptionInfo(limit=1):
 
     :Parameter limit: the number of stack trace entries to be printed
     """
-    logger = logging.getLogger(__name__)
-    logger.error('{0}'.format(traceback.format_exc(limit)))
+    log.error('{0}'.format(traceback.format_exc(limit)))
 
 #
 # Path related functions
@@ -637,7 +618,7 @@ def getFinalName(nodename, sibling, pattern, info):
             nodename = dialog.action['new_name']
             overwrite = dialog.action['overwrite']
             del dialog
-            if overwrite == True:
+            if overwrite is True:
                 break
             # Update the bad nodename condition
             nodename_in_sibling = nodename in sibling
@@ -654,6 +635,31 @@ def getLicense():
 
     resource_package = __name__
     resource_path = 'LICENSE.html'
-    license_text = pkg_resources.resource_string(resource_package, resource_path)  # @UndefinedVariable
+    license_text = pkg_resources.resource_string(
+        resource_package, resource_path)
 
     return license_text.decode('UTF-8')
+
+
+def isDataSourceReadable(leaf):
+    """Find out if the PyTables leaf can be read or not.
+    This is not a complex test. It simply try to read a small chunk
+    of data at the beginning of the dataset. If it cannot then the
+    dataset is considered unreadable.
+    """
+
+    readable = True
+    try:
+        leaf.read(0, 1)
+    except tables.HDF5ExtError as e:
+        readable = False
+        log.error(
+            """Problems reading records. The dataset seems to be """
+            """compressed with the {0} library. Check that it is """
+            """installed in your system, please.\n{1}""".format(
+                leaf.filters.complib, e.message))
+    except ValueError as e:
+        readable = False
+        log.error('Data read error: {}'.format(e.message))
+    finally:
+        return readable
