@@ -1,5 +1,5 @@
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2017 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -22,8 +22,6 @@ controls the managers for specific tasks and contains the logic for reacting
 to user's input i.e. the slots connected to every menu entry are defined here.
 """
 
-__docformat__ = 'restructuredtext'
-
 import os
 import time
 import sys
@@ -36,6 +34,7 @@ from qtpy import QtGui
 from qtpy import QtWidgets
 
 import vitables.utils
+import vitables.filenodeutils as fnutils
 import vitables.vtsplash
 from vitables.vtsite import ICONDIR
 
@@ -43,9 +42,6 @@ from vitables.preferences import vtconfig
 import vitables.preferences.pluginsloader as pluginsloader
 from vitables.preferences import preferences
 
-import vitables.h5db.dbstreemodel as dbstreemodel
-import vitables.h5db.dbstreeview as dbstreeview
-
 import vitables.queries.querymgr as qmgr
 
 import vitables.vtwidgets.nodenamedlg as nodenamedlg
@@ -53,15 +49,20 @@ import vitables.vtwidgets.renamedlg as renamedlg
 
 from vitables.docbrowser import helpbrowser
 
-import vitables.vttables.buffer as rbuffer
 import vitables.vttables.datasheet as datasheet
 
+import vitables.csv.import_csv as importcsv
+import vitables.csv.export_csv as exportcsv
+
 import vitables.vtgui as vtgui
 
+__docformat__ = 'restructuredtext'
+
 translate = QtWidgets.QApplication.translate
+log = logging.getLogger(__name__)
 
 
-def makePage(content):
+def _makePage(content):
     """Create a page for the About ViTables dialog.
 
     :Parameter content: the text displayed on the page
@@ -92,7 +93,7 @@ class VTApp(QtCore.QObject):
     # when a new plugin is added to ViTables. They are the link between
     # the plugins and the core of the program
     leaf_model_created = QtCore.Signal(QtWidgets.QMdiSubWindow,
-                                           name="leafModelCreated")
+                                       name="leafModelCreated")
     dbtree_model_created = QtCore.Signal()
     pluginsLoaded = QtCore.Signal()
 
@@ -107,9 +108,6 @@ class VTApp(QtCore.QObject):
 
         super(VTApp, self).__init__()
 
-        self.logger = logging.getLogger(__name__)
-        self.logger.setLevel(logging.INFO)
-
         # Make the main window easily accessible for external modules
         self.setObjectName('VTApp')
 
@@ -121,9 +119,6 @@ class VTApp(QtCore.QObject):
         splash.show()
         t_i = time.time()
 
-        # Instantiate a configurator object for the application
-        self.config = vtconfig.Config()
-
         # Create the GUI. This is done in 3 steps:
         # - create the main window
         # - create the model/view for the tree of databases
@@ -136,11 +131,13 @@ class VTApp(QtCore.QObject):
         splash.drawMessage(translate('VTApp', 'Configuration setup...',
                                      'A splash screen message'))
 
-        # Reset the configuration object. I don't know why this is necessary
-        # but it is
-        del self.config
+        # Instantiate a configurator object for the application
         self.config = vtconfig.Config()
-        self.config.loadConfiguration(self.config.readConfiguration())
+        self.config.applyConfiguration(self.config.readConfiguration())
+
+        # Add import/export CSV capabilities
+        self.csv_importer = importcsv.ImportCSV()
+        self.csv_exporter = exportcsv.ExportToCSV()
 
         # Load plugins.
         # Some plugins modify existing menus so plugins must be loaded after
@@ -159,7 +156,7 @@ class VTApp(QtCore.QObject):
         # Print the welcome message
         self.gui.logger.write(
             translate('VTApp',
-                      """ViTables {0}\nCopyright (c) 2008-2017 Vicent Mas."""
+                      """ViTables {0}\nCopyright (c) 2008-2019 Vicent Mas."""
                       """\nAll rights reserved.""",
                       'Application startup message').format(
                           vtconfig.getVersion()))
@@ -171,13 +168,18 @@ class VTApp(QtCore.QObject):
 
         # The File Selector History
         self.file_selector_history = []
-        if self.config.startup_working_directory != 'last':
+        if self.config.initial_working_directory != 'last':
+            # Reset the last working directory if the Session/startupWorkingDir
+            # setting is not 'last'
             self.config.last_working_directory = os.getcwd()
         self.file_selector_history.append(self.config.last_working_directory)
 
         # List of HelpBrowser instances in memory
         self.doc_browser = None
 
+        # Filenodes mappig
+        self.filenodes_map = {}
+
         # Restore last session
         if self.config.restore_last_session:
             splash.drawMessage(translate('VTApp', 'Recovering last session...',
@@ -266,7 +268,7 @@ class VTApp(QtCore.QObject):
                 self.gui.dbs_tree_view.expanded.emit(index)
                 groups.pop(0)
                 # Expand the rest of groups of the nodepath
-                while groups != []:
+                while groups:
                     parent_group = group
                     parent_index = index
                     group = parent_group.findChild(groups[0])
@@ -316,14 +318,14 @@ class VTApp(QtCore.QObject):
                     if line == ['']:
                         continue
                     if len(line) != 2:
-                        self.logger.error(bad_line.format('format', line,
-                                                          dblist))
+                        log.error(bad_line.format('format', line,
+                                                  dblist))
                         continue
                     [mode, filepath] = line
                     filepath = vitables.utils.forwardPath(filepath)
-                    if not mode in ['r', 'a']:
-                        self.logger.error(bad_line.format('mode', line,
-                                                          dblist))
+                    if mode not in ['r', 'a']:
+                        log.error(bad_line.format('mode', line,
+                                                  dblist))
                         continue
                     if self.gui.dbs_tree_model.openDBDoc(filepath, mode):
                         self.gui.dbs_tree_view.setCurrentIndex(
@@ -332,7 +334,7 @@ class VTApp(QtCore.QObject):
                         self.updateRecentFiles(filepath, mode)
 
             except IOError:
-                self.logger.error(
+                log.error(
                     translate('VTApp', 'List of HDF5 files not read',
                               'File not updated error'))
 
@@ -366,6 +368,7 @@ class VTApp(QtCore.QObject):
         :Parameter working_dir: the last visited directory
         """
 
+        # Update the Session/lastWorkingDir setting
         self.config.last_working_directory = working_dir
         if working_dir not in self.file_selector_history:
             self.file_selector_history.append(working_dir)
@@ -388,8 +391,9 @@ class VTApp(QtCore.QObject):
             translate('VTApp', 'Creating a new file...',
                       'Caption of the File New... dialog'),
             dfilter=translate('VTApp',
-                """HDF5 Files (*.hdf *.h5 *.hd5 *.hdf5);;"""
-                """All Files (*)""", 'Filter for the Open New dialog'),
+                              """HDF5 Files (*.hdf *.h5 *.hd5 *.hdf5);;"""
+                              """All Files (*)""",
+                              'Filter for the Open New dialog'),
             settings=fs_args)
 
         if not filepath:
@@ -404,7 +408,7 @@ class VTApp(QtCore.QObject):
 
         # Check the returned path
         if os.path.exists(filepath):
-            self.logger.error(
+            log.error(
                 translate('VTApp', 'New file creation failed because file '
                           'already exists.', 'A file creation error'))
             return
@@ -463,7 +467,7 @@ class VTApp(QtCore.QObject):
         #
 
         info = [translate('VTApp', 'File Save as: file already exists',
-                'A dialog caption'), None]
+                          'A dialog caption'), None]
         # Bad filepath conditions
         trier_dirname, trier_filename = os.path.split(trier_filepath)
         sibling = os.listdir(trier_dirname)
@@ -479,26 +483,29 @@ class VTApp(QtCore.QObject):
         while is_tmp_filepath or is_initial_filepath or filename_in_sibling:
             if is_tmp_filepath:
                 info[1] = translate('VTApp',
-                    """Target directory: {0}\n\nThe Query results"""
-                    """ database cannot be overwritten.""",
-                    'Overwrite file dialog label').format(trier_dirname)
+                                    """Target directory: {0}\n\nThe Query """
+                                    """results database cannot be """
+                                    """overwritten.""",
+                                    'Overwrite file dialog label').format(
+                    trier_dirname)
                 template = \
                     "(^{0}$)|[a-zA-Z_]+[0-9a-zA-Z_]*(?:\.[0-9a-zA-Z_]+)?$"
                 pattern = template.format(trier_filename)
             elif is_initial_filepath:
                 info[1] = translate('VTApp',
-                    """Target directory: {0}\n\nThe file being """
-                    """saved cannot overwrite itself.""",
-                    'Overwrite file dialog label').format(trier_dirname)
+                                    """Target directory: {0}\n\nThe file """
+                                    """being saved cannot overwrite itself.""",
+                                    'Overwrite file dialog label').format(
+                    trier_dirname)
                 template = \
                     "(^{0}$)|[a-zA-Z_]+[0-9a-zA-Z_]*(?:\.[0-9a-zA-Z_]+)?$"
                 pattern = template.format(trier_filename)
             elif filename_in_sibling:
                 info[1] = translate('VTApp',
-                    """Target directory: {0}\n\nFile name {1}"""
-                    """ already in use in that directory.\n""",
-                    'Overwrite file dialog label').format(trier_dirname,
-                    trier_filename)
+                                    """Target directory: {0}\n\nFile name {1}"""
+                                    """ already in use in that directory.\n""",
+                                    'Overwrite file dialog label').format(
+                    trier_dirname, trier_filename)
                 pattern = "[a-zA-Z_]+[0-9a-zA-Z_]*(?:\.[0-9a-zA-Z_]+)?$"
 
             dialog = renamedlg.RenameDlg(trier_filename, pattern, info)
@@ -514,7 +521,7 @@ class VTApp(QtCore.QObject):
                     trier_filepath == self.gui.dbs_tree_model.tmp_filepath
                 filename_in_sibling = trier_filename in sibling
                 del dialog
-                if (overwrite == True) and (not is_initial_filepath) and \
+                if (overwrite is True) and (not is_initial_filepath) and \
                         (not is_tmp_filepath):
                     break
             else:
@@ -527,12 +534,13 @@ class VTApp(QtCore.QObject):
         if overwrite and self.gui.dbs_tree_model.getDBDoc(filepath):
             for row, child in enumerate(self.gui.dbs_tree_model.root.children):
                 if child.filepath == filepath:
-                    self.fileClose(self.gui.dbs_tree_model.index(row, 0,
-                                                        QtCore.QModelIndex()))
+                    self.fileClose(self.gui.dbs_tree_model.index(
+                        row, 0, QtCore.QModelIndex()))
             # The current index could have changed when overwriting
             # so we update it
             for row in range(0,
-                self.gui.dbs_tree_model.rowCount(QtCore.QModelIndex())):
+                             self.gui.dbs_tree_model.rowCount(
+                                 QtCore.QModelIndex())):
                 index = QtCore.QModelIndex().child(row, 0)
                 node = self.gui.dbs_tree_model.nodeFromIndex(index)
                 if node.filepath == initial_filepath:
@@ -541,7 +549,8 @@ class VTApp(QtCore.QObject):
 
         # Make a copy of the selected file
         try:
-            QtWidgets.qApp.setOverrideCursor(QtGui.QCursor(QtCore.Qt.WaitCursor))
+            QtWidgets.qApp.setOverrideCursor(
+                QtGui.QCursor(QtCore.Qt.WaitCursor))
             dbdoc = self.gui.dbs_tree_model.getDBDoc(initial_filepath)
             dbdoc.copy_file(filepath)
         finally:
@@ -602,17 +611,19 @@ class VTApp(QtCore.QObject):
         if not filepath:
             # Launch the file selector
             fs_args = {'accept_mode': QtWidgets.QFileDialog.AcceptOpen,
-                'file_mode': QtWidgets.QFileDialog.ExistingFile,
-                'history': self.file_selector_history,
-                'label':
-                    translate('VTApp', 'Open', 'Accept text for QFileDialog')}
+                       'file_mode': QtWidgets.QFileDialog.ExistingFile,
+                       'history': self.file_selector_history,
+                       'label':
+                       translate('VTApp', 'Open', 'Accept text for QFileDialog')
+                       }
             filepath, working_dir = vitables.utils.getFilepath(
                 self.gui,
                 translate('VTApp', 'Select a file for opening',
-                'Caption of the File Open... dialog'),
-                dfilter = translate('VTApp',
-                    """HDF5 Files (*.hdf *.h5 *.hd5 *.hdf5);;"""
-                    """All Files (*)""", 'Filter for the Open New dialog'),
+                          'Caption of the File Open... dialog'),
+                dfilter=translate('VTApp',
+                                  """HDF5 Files (*.hdf *.h5 *.hd5 *.hdf5);;"""
+                                  """All Files (*)""",
+                                  'Filter for the Open New dialog'),
                 settings=fs_args)
 
             if not filepath:
@@ -633,7 +644,6 @@ class VTApp(QtCore.QObject):
                     position, 0, QtCore.QModelIndex()))
             self.updateRecentFiles(filepath, mode)
 
-
     def fileClose(self, current=False):
         """
         Close a file.
@@ -672,10 +682,9 @@ class VTApp(QtCore.QObject):
         # The root node immediately below the closed node becomes selected
         if position <= last_row:
             index = self.gui.dbs_tree_model.index(position, 0,
-                QtCore.QModelIndex())
+                                                  QtCore.QModelIndex())
             self.gui.dbs_tree_view.setCurrentIndex(index)
 
-
     def fileCloseAll(self):
         """Close every open file."""
 
@@ -689,7 +698,6 @@ class VTApp(QtCore.QObject):
             index = self.gui.dbs_tree_model.index(row, 0, QtCore.QModelIndex())
             self.fileClose(index)
 
-
     def fileExit(self):
         """
         Safely close the application.
@@ -697,14 +705,6 @@ class VTApp(QtCore.QObject):
         Saves current configuration on disk, closes opened files and exits.
         """
 
-        # Because configuration is always restored from the previous session
-        # we have to be careful with the Logger and make sure that it is neither
-        # closed nor floated
-        if not self.gui.logger_dock.isVisible():
-            self.gui.logger_dock.setVisible(True)
-        if self.gui.logger_dock.isFloating():
-            self.gui.logger_dock.setFloating(False)
-
         # Close all browsers
         if self.doc_browser:
             self.doc_browser.exitBrowser()
@@ -716,7 +716,6 @@ class VTApp(QtCore.QObject):
         index = self.gui.dbs_tree_model.index(0, 0, QtCore.QModelIndex())
         self.fileClose(index)
 
-
     def tablesNode(self, index):
         """The tables.Leaf instance tied to the given index.
 
@@ -731,7 +730,7 @@ class VTApp(QtCore.QObject):
             return pt_node()
         return pt_node
 
-
+    @vitables.utils.long_action("Opening node...")
     def nodeOpen(self, current=False):
         """
         Open a leaf node for viewing.
@@ -750,25 +749,29 @@ class VTApp(QtCore.QObject):
 
         # tables.UnImplemented datasets cannot be read so are not opened
         if isinstance(leaf, tables.UnImplemented):
-            QtWidgets.QMessageBox.information(self.gui,
+            QtWidgets.QMessageBox.information(
+                self.gui, translate('VTApp', 'About UnImplemented nodes',
+                                    'A dialog caption'),
                 translate('VTApp',
-                    'About UnImplemented nodes', 'A dialog caption'),
-                translate('VTApp',
-                """Actual data for this node are not accesible.<br> """
-                """The combination of datatypes and/or dataspaces in this """
-                """node is not yet supported by PyTables.<br>"""
-                """If you want to see this kind of dataset implemented in """
-                """PyTables, please, contact the developers.""",
-                'Text of the Unimplemented node dialog'))
+                          """Actual data for this node are not accesible."""
+                          """<br> The combination of datatypes and/or """
+                          """dataspaces in this node is not yet supported by """
+                          """PyTables.<br>If you want to see this kind of """
+                          """dataset implemented in PyTables, please, """
+                          """contact the developers.""",
+                          'Text of the Unimplemented node dialog'))
             return
 
-        # The buffer tied to this node in order to optimize the read access
-        leaf_buffer = rbuffer.Buffer(leaf)
-
         # Leaves that cannot be read are not opened
-        if not leaf_buffer.isDataSourceReadable():
+        if not vitables.utils.isDataSourceReadable(leaf):
             return
 
+        # Track filenodes
+        if fnutils.isFilenode(leaf) and (leaf not in self.filenodes_map):
+            temp_filenode = fnutils.filenodeToFile(leaf)
+            self.filenodes_map[leaf] = (temp_filenode,
+                                        fnutils.filenodeTotalRows(leaf))
+
         # Create a view
         subwindow = datasheet.DataSheet(index)
         subwindow.show()
@@ -782,7 +785,6 @@ class VTApp(QtCore.QObject):
         # of datasets customizations (for instance, additional formatting)
         self.leaf_model_created.emit(subwindow)
 
-
     def nodeClose(self, current=False):
         """
         Close the view of the selected node.
@@ -808,7 +810,6 @@ class VTApp(QtCore.QObject):
                 data_sheet.close()
                 break
 
-
     def nodeNewGroup(self):
         """Create a new group node."""
 
@@ -819,7 +820,8 @@ class VTApp(QtCore.QObject):
         dialog = nodenamedlg.InputNodeName(
             translate('VTApp', 'Creating a new group', 'A dialog caption'),
             translate('VTApp', 'Source file: {0}\nParent group: {1}\n\n ',
-                      'A dialog label').format(parent.filepath, parent.nodepath),
+                      'A dialog label').format(parent.filepath,
+                                               parent.nodepath),
             translate('VTApp', 'Create', 'A button label'))
         self.gui.editing_dlg = True
         if dialog.exec_():
@@ -837,15 +839,17 @@ class VTApp(QtCore.QObject):
         sibling = getattr(parent.node, '_v_children').keys()
         pattern = "[a-zA-Z_]+[0-9a-zA-Z_ ]*"
         info = [translate('VTApp',
-                    'Creating a new group: name already in use',
-                    'A dialog caption'),
+                          'Creating a new group: name already in use',
+                          'A dialog caption'),
                 translate('VTApp',
-                    """Source file: {0}\nParent group: {1}\n\nThere is """
-                    """already a node named '{2}' in that parent group.\n""",
-                    'A dialog label').format\
-                    (parent.filepath, parent.nodepath, suggested_nodename)]
+                          """Source file: {0}\nParent group: {1}\n\nThere is """
+                          """already a node named '{2}' in that parent group."""
+                          """\n""",
+                          'A dialog label').format
+                (parent.filepath, parent.nodepath, suggested_nodename)]
         nodename, overwrite = vitables.utils.getFinalName(suggested_nodename,
-            sibling, pattern, info)
+                                                          sibling, pattern,
+                                                          info)
         if nodename is None:
             return
 
@@ -857,7 +861,6 @@ class VTApp(QtCore.QObject):
 
         self.gui.dbs_tree_model.create_group(current, nodename, overwrite)
 
-
     def nodeRename(self):
         """
         Rename the selected node.
@@ -876,7 +879,8 @@ class VTApp(QtCore.QObject):
         dialog = nodenamedlg.InputNodeName(
             translate('VTApp', 'Renaming a node', 'A dialog caption'),
             translate('VTApp', 'Source file: {0}\nParent group: {1}\n\n',
-                      'A dialog label').format(parent.filepath, parent.nodepath),
+                      'A dialog label').format(parent.filepath,
+                                               parent.nodepath),
             translate('VTApp', 'Rename', 'A button label'),
             child.name)
         self.gui.editing_dlg = True
@@ -897,14 +901,15 @@ class VTApp(QtCore.QObject):
         pattern = """(^{0}$)|""" \
             """(^[a-zA-Z_]+[0-9a-zA-Z_ ]*)""".format(child.name)
         info = [translate('VTApp', 'Renaming a node: name already in use',
-                'A dialog caption'),
+                          'A dialog caption'),
                 translate('VTApp',
-                    """Source file: {0}\nParent group: {1}\n\nThere is """
-                    """already a node named '{2}' in that parent """
-                    """group.\n""", 'A dialog label').format\
-                    (parent.filepath, parent.nodepath, suggested_nodename)]
+                          """Source file: {0}\nParent group: {1}\n\nThere is """
+                          """already a node named '{2}' in that parent """
+                          """group.\n""", 'A dialog label').format
+                (parent.filepath, parent.nodepath, suggested_nodename)]
         nodename, overwrite = vitables.utils.getFinalName(suggested_nodename,
-            sibling, pattern, info)
+                                                          sibling, pattern,
+                                                          info)
         self.gui.editing_dlg = True
         if nodename is None:
             return
@@ -921,7 +926,6 @@ class VTApp(QtCore.QObject):
         # Update the Selected node indicator of the status bar
         self.gui.updateStatusBar()
 
-
     def nodeCut(self):
         """Cut the selected node."""
 
@@ -937,7 +941,6 @@ class VTApp(QtCore.QObject):
         # Cut the node
         self.gui.dbs_tree_model.cutNode(current)
 
-
     def nodeCopy(self):
         """
         Copy the selected node.
@@ -951,21 +954,20 @@ class VTApp(QtCore.QObject):
             leaf = dbs_tree_node.node
             # tables.Leaf instances must be readable in order to be copied
             if not hasattr(leaf, 'target'):
-                leaf_buffer = rbuffer.Buffer(leaf)
-                if not leaf_buffer.isDataSourceReadable():
-                    QtWidgets.QMessageBox.information(self,
+                if not vitables.utils.isDataSourceReadable(leaf):
+                    QtWidgets.QMessageBox.information(
+                        self,
                         translate('VTApp', 'About unreadable datasets',
-                            'Dialog caption'),
-                        translate('VTApp',
-                            """Sorry, actual data for this node are not """
-                            """accesible.<br>The node will not be copied.""",
-                            'Text of the Unimplemented node dialog'))
+                                  'Dialog caption'),
+                        translate('VTApp', """Sorry, actual data for this """
+                                           """node are not accesible.<br>The """
+                                           """node will not be copied.""",
+                                  'Text of the Unimplemented node dialog'))
                     return
 
         # Copy the node
         self.gui.dbs_tree_model.copy_node(current)
 
-
     def nodePaste(self):
         """
         Paste the currently copied/cut node under the selected node.
@@ -988,7 +990,7 @@ class VTApp(QtCore.QObject):
             # node has no restrictions). It is not when
             # - source and target are the same node
             # - target is the source's parent
-            if (cni['filepath'] == parent.filepath):
+            if cni['filepath'] == parent.filepath:
                 if (cni['nodepath'] == parent.nodepath) or \
                         (parent.nodepath == os.path.dirname(cni['nodepath'])):
                     return
@@ -999,7 +1001,7 @@ class VTApp(QtCore.QObject):
             try:
                 getattr(link, 'extfile')
             except AttributeError:
-                if (parent.filepath != cni['filepath']):
+                if parent.filepath != cni['filepath']:
                     return
 
         #
@@ -1010,17 +1012,17 @@ class VTApp(QtCore.QObject):
         pattern = "[a-zA-Z_]+[0-9a-zA-Z_ ]*"
         # Bad nodename conditions
         info = [translate('VTApp', 'Node paste: nodename already exists',
-                'A dialog caption'),
+                          'A dialog caption'),
                 translate('VTApp', """Source file: {0}\nCopied node: {1}\n"""
-                    """Destination file: {2}\nParent group: {3}\n\n"""
-                    """Node name '{4}' already in use in that group.\n""",
-                    'A dialog label').format\
-                    (cni['filepath'], cni['nodepath'], parent.filepath,
-                    parent.nodepath, nodename),
+                          """Destination file: {2}\nParent group: {3}\n\n"""
+                          """Node name '{4}' already in use in that group.\n""",
+                          'A dialog label').format
+                (cni['filepath'], cni['nodepath'], parent.filepath,
+                 parent.nodepath, nodename),
                 translate('VTApp', 'Paste', 'A button label')]
         # Validate the nodename
         nodename, overwrite = vitables.utils.getFinalName(nodename, sibling,
-            pattern, info)
+                                                          pattern, info)
         self.gui.editing_dlg = True
         if nodename is None:
             # Node editing dialog is not displayed
@@ -1035,7 +1037,6 @@ class VTApp(QtCore.QObject):
         # Paste the node
         self.gui.dbs_tree_model.pasteNode(current, nodename, overwrite)
 
-
     def nodeDelete(self, current=False, force=None):
         """
         Delete a given node.
@@ -1054,20 +1055,20 @@ class VTApp(QtCore.QObject):
         # Confirm deletion dialog
         if not force:
             title = translate('VTApp', 'Node deletion',
-                'Caption of the node deletion dialog')
+                              'Caption of the node deletion dialog')
             text = translate('VTApp',
-                """\nYou are about to delete the node:\n{0}\n""",
-                'Ask for confirmation').format(node.nodepath)
+                             """\nYou are about to delete the node:\n{0}\n""",
+                             'Ask for confirmation').format(node.nodepath)
             itext = ''
             dtext = ''
             buttons = {
                 'Delete':
                     (translate('VTApp', 'Delete', 'Button text'),
-                    QtWidgets.QMessageBox.YesRole),
+                     QtWidgets.QMessageBox.YesRole),
                 'Cancel':
                     (translate('VTApp', 'Cancel', 'Button text'),
-                    QtWidgets.QMessageBox.NoRole),
-                }
+                     QtWidgets.QMessageBox.NoRole),
+            }
 
             # Ask for confirmation
             answer = \
@@ -1092,7 +1093,6 @@ class VTApp(QtCore.QObject):
         new_current = self.gui.dbs_tree_view.currentIndex()
         select_model.select(new_current, QtCore.QItemSelectionModel.Select)
 
-
     def nodeProperties(self):
         """
         Display the properties dialog for the currently selected node.
@@ -1105,17 +1105,14 @@ class VTApp(QtCore.QObject):
         node.properties()
         self.gui.editing_dlg = True
 
-
     def newQuery(self):
         """Slot for querying tables."""
         self.queries_mgr.newQuery()
 
-
     def deleteAllQueries(self):
         """Slot for emptying the `Query results` node."""
         self.queries_mgr.deleteAllQueries()
 
-
     def settingsPreferences(self):
         """
         Launch the Preferences dialog.
@@ -1124,22 +1121,20 @@ class VTApp(QtCore.QObject):
         Preferences dialog.
         """
 
-        prefs =  preferences.Preferences()
+        prefs = preferences.Preferences()
         try:
             if prefs.exec_() == QtWidgets.QDialog.Accepted:
-                self.config.loadConfiguration(prefs.new_prefs)
+                self.config.applyConfiguration(prefs.new_prefs)
         finally:
             del prefs
 
-
     def windowClose(self):
         """Close the window currently active in the workspace."""
 
         self.gui.workspace.activeSubWindow().close()
-        if self.gui.workspace.subWindowList() == []:
+        if not self.gui.workspace.subWindowList():
             self.gui.dbs_tree_view.setFocus(True)
 
-
     def windowCloseAll(self):
         """Close all open windows."""
 
@@ -1147,72 +1142,65 @@ class VTApp(QtCore.QObject):
             window.close()
         self.gui.dbs_tree_view.setFocus(True)
 
-
     def windowRestoreAll(self):
         """Restore every window in the workspace to its normal size."""
 
         for window in self.gui.workspace.subWindowList():
             window.showNormal()
 
-
     def windowMinimizeAll(self):
         """Restore every window in the workspace to its normal size."""
 
         for window in self.gui.workspace.subWindowList():
             window.showMinimized()
 
-
     def helpBrowser(self):
         """
         Open the documentation browser.
         """
         self.doc_browser = helpbrowser.HelpBrowser()
 
-
     def helpAbout(self):
         """
         Show a tabbed dialog with the application About and License info.
         """
 
         # Text to be displayed
-        about_text = translate('VTApp',
-            """<qt>
-            <h3>ViTables {0}</h3>
+        about_text = translate('VTApp', """<qt><h3>ViTables {0}</h3>
             ViTables is a graphical tool for displaying datasets
             stored in PyTables and HDF5 files. It is written using PyQt
             , the Python bindings for the Qt GUI toolkit.<p>
             For more information see
-            <b>http://www.vitables.org</b>.<p>
+            <b>https://vitables.org</b>.<p>
             Please send bug reports or feature requests to the
             <em>ViTables Users Group</em>.<p>
             ViTables uses third party software which is copyrighted by
             its respective copyright holder. For details see the
             copyright notice of the individual packages.
-            </qt>""",
-            'Text of the About ViTables dialog').format(vtconfig.getVersion())
-        thanks_text = translate('VTApp',
-            """<qt>
-            Kostis Anagnostopoulos, Arne de Laat and Christoph Gohlke for 
-            helping to revive ViTables with his great contributions.<p>
+            </qt>""", 'Text of the About ViTables dialog').format(
+            vtconfig.getVersion())
+        thanks_text = translate('VTApp', """<qt>
+            Jens Janssen, Kostis Anagnostopoulos, Arne de Laat and Christoph
+            Gohlke for
+            helping to revive ViTables with their great contributions.<p>
             Santi Villalba for the conda environment.<p>
             Alexey Naydenov for his contributions to the plugins system and for
             providing logging support to the application.<p>
-            Robert Meyer, jaminsore, kprussing, Gaetan de Menten, Kamil Kisiel 
+            Robert Meyer, jaminsore, kprussing, Gaetan de Menten, Kamil Kisiel
             and Max Bohnet for fixing bugs.<p>
             Dmitrijs Ledkovs for contributing the new and greatly enhanced
             build system and for making Debian packages.<p>
             Oxygen team for a wonderful icons set.<p>
             All the people who reported bugs and made suggestions.
-            </qt>""",
-            'Text of the About ViTables dialog (Thanks to page)')
+            </qt>""", 'Text of the About ViTables dialog (Thanks to page)')
         license_text = vitables.utils.getLicense()
 
         # Construct the dialog
         about_dlg = QtWidgets.QDialog(self.gui)
         about_dlg.setWindowTitle(
             translate('VTApp', 'About ViTables {0}',
-                'Caption of the About ViTables dialog').\
-                format(vtconfig.getVersion()))
+                      'Caption of the About ViTables dialog').
+            format(vtconfig.getVersion()))
         layout = QtWidgets.QVBoxLayout(about_dlg)
         tab_widget = QtWidgets.QTabWidget(about_dlg)
         buttons_box = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Ok)
@@ -1224,28 +1212,25 @@ class VTApp(QtCore.QObject):
         # Make About page
         content = [about_text, thanks_text, license_text]
         tabs = [translate('VTApp', '&About',
-            'Title of the first tab of the About dialog'),
-            translate('VTApp', '&Thanks To',
-            'Title of the second tab of the About dialog'),
-            translate('VTApp', '&License',
-            'Title of the third tab of the About dialog')]
+                          'Title of the first tab of the About dialog'),
+                translate('VTApp', '&Thanks To',
+                          'Title of the second tab of the About dialog'),
+                translate('VTApp', '&License',
+                          'Title of the third tab of the About dialog')]
 
         for index in range(0, 3):
-            widget = makePage(content[index])
+            widget = _makePage(content[index])
             tab_widget.addTab(widget, tabs[index])
 
-
         # Show the dialog
         about_dlg.exec_()
 
-
     def helpAboutQt(self):
         """
         Show a message box with the Qt About info.
         """
-        QtWidgets.QMessageBox.aboutQt(self.gui, translate('VTApp', 'About Qt',
-            'Caption of the About Qt dialog'))
-
+        QtWidgets.QMessageBox.aboutQt(self.gui, translate(
+            'VTApp', 'About Qt', 'Caption of the About Qt dialog'))
 
     def helpVersions(self):
         """
@@ -1258,9 +1243,9 @@ class VTApp(QtCore.QObject):
         # The libraries versions dictionary
         libs_versions = {
             'title': translate('VTApp', 'Version Numbers',
-                'Caption of the Versions dialog'),
+                               'Caption of the Versions dialog'),
             'Python': pyversion,
-            'PyTables': tables.__version__ ,
+            'PyTables': tables.__version__,
             'NumPy': tables.numpy.__version__,
             'Qt': QtCore.qVersion(),
             'PyQt': QtCore.PYQT_VERSION_STR,
@@ -1274,13 +1259,14 @@ class VTApp(QtCore.QObject):
             if lversion:
                 libs_versions[lib] = lversion[1]
             else:
-                libs_versions[lib] = translate('VTApp', 'not available',
+                libs_versions[lib] = translate(
+                    'VTApp', 'not available',
                     'Part of the library not found text')
 
         # Construct the dialog
         versions_dlg = QtWidgets.QDialog(self.gui)
         versions_dlg.setWindowTitle(translate('VTApp', 'Version Numbers',
-                                             'Caption of the Versions dialog'))
+                                              'Caption of the Versions dialog'))
         layout = QtWidgets.QVBoxLayout(versions_dlg)
         versions_edit = QtWidgets.QTextEdit(versions_dlg)
         buttons_box = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Ok)
@@ -1318,7 +1304,7 @@ class VTApp(QtCore.QObject):
                 Zlib=libs_versions['Zlib'],
                 LZO=libs_versions['LZO'],
                 BZIP2=libs_versions['BZIP2'],
-                ))
+            ))
 
         # Show the dialog
         versions_dlg.exec_()
