@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2017 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -24,20 +24,19 @@ This module provides de `ViTables` GUI: main window, menus, context menus,
 toolbars, statusbars and `QActions` bound to both menus and toolbars.
 """
 
-__docformat__ = 'restructuredtext'
-
-import sys
 import logging
+from vitables.calculator import calculator
+import vitables.utils
 
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
 
-import vitables.utils
-import vitables.logger as logger
-from vitables.calculator import calculator
 import vitables.h5db.dbstreemodel as dbstreemodel
 import vitables.h5db.dbstreeview as dbstreeview
+import vitables.logger as logger
+
+__docformat__ = 'restructuredtext'
 
 translate = QtWidgets.QApplication.translate
 
@@ -84,7 +83,7 @@ class VTGUI(QtWidgets.QMainWindow):
         :Parameter tree_view: The databases tree view
         """
 
-        self.dbs_tree_model =  dbstreemodel.DBsTreeModel(self, vtapp)
+        self.dbs_tree_model = dbstreemodel.DBsTreeModel(self, vtapp)
         self.dbs_tree_view = dbstreeview.DBsTreeView(vtapp, self,
                                                      self.dbs_tree_model,
                                                      self)
@@ -99,13 +98,14 @@ class VTGUI(QtWidgets.QMainWindow):
     def setup_logger_window(self):
         # Put the logging console in the bottom region of the window
         self.logger_dock = QtWidgets.QDockWidget('Log')
-        self.logger_dock.setObjectName('LoggerDockWindow')
+        self.logger_dock.setObjectName('LoggerDockWidget')
         self.logger_dock.setFeatures(
             QtWidgets.QDockWidget.DockWidgetClosable
             | QtWidgets.QDockWidget.DockWidgetMovable
             | QtWidgets.QDockWidget.DockWidgetFloatable)
         self.addDockWidget(QtCore.Qt.BottomDockWidgetArea, self.logger_dock)
-        self.logger = logger.Logger()
+        self.logger = logger.Logger(self)
+        self.logger.setObjectName('LoggerWidget')
         self.logger_dock.setWidget(self.logger)
         # add self.logger as handler of main logger object
         vitables_logger = logging.getLogger('vitables')
@@ -113,7 +113,6 @@ class VTGUI(QtWidgets.QMainWindow):
         stream_handler.setFormatter(logging.Formatter(_GUI_LOG_FORMAT))
         vitables_logger.addHandler(stream_handler)
 
-
     def addComponents(self):
         """Add widgets to the main window.
 
@@ -128,7 +127,9 @@ class VTGUI(QtWidgets.QMainWindow):
         central_layout = QtWidgets.QVBoxLayout(central_widget)
         # Divide the top region of the window into 2 regions and put there
         # the workspace. The tree of databases will be added later on
-        self.hsplitter = QtWidgets.QSplitter(QtCore.Qt.Horizontal, central_widget)
+        self.hsplitter = QtWidgets.QSplitter(
+            QtCore.Qt.Horizontal, central_widget)
+        self.hsplitter.setObjectName('hsplitter')
         central_layout.addWidget(self.hsplitter)
         self.setCentralWidget(central_widget)
         self.hsplitter.addWidget(self.dbs_tree_view)
@@ -405,7 +406,9 @@ class VTGUI(QtWidgets.QMainWindow):
             translate('VTGUI', 'Toggle MDI/Tabs', 'MDI -> Tabbed'), self,
             triggered=self.changeMDIViewMode,
             statusTip=translate(
-                'VTGUI', 'Toggle workspace view mode between Tabs <--> Multi Document Interface',
+                'VTGUI',
+                'Toggle workspace view mode between Tabs <--> Multi Document '
+                'Interface',
                 'Status bar text for the MDI -> Tabbed action'))
         actions['mdiTabbed'].setObjectName('mdiTabbed')
 
@@ -469,7 +472,7 @@ class VTGUI(QtWidgets.QMainWindow):
         # Warning! Do NOT use 'File toolbar' as a object name or it will
         # show an strange behaviour (a Qt bug I think): it will always
         # be added to the left and will expand the whole top area
-        self.file_toolbar.setObjectName('File')
+        self.file_toolbar.setObjectName('File toolbar')
         actions = ['fileNew', 'fileOpen', 'fileClose', 'fileSaveAs']
         vitables.utils.addActions(self.file_toolbar, actions, self.gui_actions)
 
@@ -503,6 +506,7 @@ class VTGUI(QtWidgets.QMainWindow):
         actions = ['helpUsersGuide']
         vitables.utils.addActions(self.help_toolbar, actions, self.gui_actions)
         whatis = QtWidgets.QWhatsThis.createAction(self.help_toolbar)
+        whatis.setObjectName('whatis_help_toolbar')
         whatis.setStatusTip(translate(
             'VTGUI', 'Whats this? help for a widget',
             'Status bar text for the Help -> Whats This action'))
@@ -514,6 +518,7 @@ class VTGUI(QtWidgets.QMainWindow):
 
         status_bar = self.statusBar()
         self.sb_node_info = QtWidgets.QLabel(status_bar)
+        self.sb_node_info.setObjectName('status bar widget')
         self.sb_node_info.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding,
                                         QtWidgets.QSizePolicy.Minimum)
         status_bar.addPermanentWidget(self.sb_node_info)
@@ -527,7 +532,7 @@ class VTGUI(QtWidgets.QMainWindow):
         """
         Set up the main window menus.
 
-        Popus are made of actions, items and separators.
+        Popups are made of actions, items and separators.
         The `Window` menu is a special case due to its dynamic nature. Its
         contents depend on the number of existing views.
         In order to track changes and keep updated the menu, it is reloaded
@@ -538,6 +543,7 @@ class VTGUI(QtWidgets.QMainWindow):
         self.file_menu = self.menuBar().addMenu(translate(
             'VTGUI', "&File", 'The File menu entry'))
         self.file_menu.setObjectName('file_menu')
+        # The Open Recent submenu
         self.open_recent_submenu = QtWidgets.QMenu(
             translate('VTGUI', 'Open R&ecent Files',
                       'File -> Open Recent Files'))
@@ -545,6 +551,7 @@ class VTGUI(QtWidgets.QMainWindow):
         self.open_recent_submenu.setSeparatorsCollapsible(False)
         self.open_recent_submenu.setIcon(
             self.icons_dictionary['document-open-recent'])
+
         file_actions = ['fileNew', 'fileOpen', 'fileOpenRO',
                         self.open_recent_submenu, None, 'fileClose',
                         'fileCloseAll', None, 'fileSaveAs', None, 'fileExit']
@@ -570,15 +577,18 @@ class VTGUI(QtWidgets.QMainWindow):
         self.dataset_menu = self.menuBar().addMenu(
             translate('VTGUI', "&Dataset", 'The Dataset menu entry'))
         self.dataset_menu.setObjectName('dataset_menu')
-        dataset_actions = ['queryNew', 'calculate', None]
+        dataset_actions = ['queryNew', 'calculate']
         vitables.utils.addActions(self.dataset_menu, dataset_actions,
                                   self.gui_actions)
 
         # Create the Settings menu and add actions/submenus/separators to it
         settings_menu = self.menuBar().addMenu(
             translate('VTGUI', "&Settings", 'The Settings menu entry'))
-        settings_menu.setObjectName('settings-menu')
+        settings_menu.setObjectName('settings_menu')
+        # Returns a popup menu containing checkable entries for the toolbars
+        # and dock widgets present in the main window
         self.toolbars_submenu = self.createPopupMenu()
+        self.toolbars_submenu.setObjectName('settings_toolbars_submenu')
         self.toolbars_submenu.menuAction().setText(
             translate('VTGUI', 'ToolBars', 'Tools -> ToolBars action'))
         settings_actions = ['settingsPreferences', None,
@@ -607,6 +617,7 @@ class VTGUI(QtWidgets.QMainWindow):
                         'helpVersions', None]
         vitables.utils.addActions(help_menu, help_actions, self.gui_actions)
         whatis = QtWidgets.QWhatsThis.createAction(help_menu)
+        whatis.setObjectName('whatis_help_menu')
         whatis.setStatusTip(
             translate('VTGUI', 'Context help',
                       'Status bar text for the Help -> Whats This action'))
@@ -618,30 +629,35 @@ class VTGUI(QtWidgets.QMainWindow):
         #
         #########################################################
 
-        self.view_cm = QtWidgets.QMenu()
+        self.view_cm = QtWidgets.QMenu(self)
+        self.view_cm.setObjectName('view_cm')
         actions = ['fileNew', 'fileOpen', 'fileOpenRO',
-                   self.open_recent_submenu, None, 'fileClose', 'fileCloseAll',
-                   None, 'fileSaveAs', None, 'fileExit']
+                   self.open_recent_submenu, None, 'fileClose',
+                   'fileCloseAll', None, 'fileSaveAs', None, 'fileExit']
         vitables.utils.addActions(self.view_cm, actions, self.gui_actions)
 
-        self.root_node_cm = QtWidgets.QMenu()
+        self.root_node_cm = QtWidgets.QMenu(self)
+        self.root_node_cm.setObjectName('root_node_cm')
         actions = ['fileClose', 'fileSaveAs', None, 'nodeProperties', None,
                    'nodeNew', 'nodeCopy', 'nodePaste', None, 'queryDeleteAll']
         vitables.utils.addActions(self.root_node_cm, actions, self.gui_actions)
 
-        self.group_node_cm = QtWidgets.QMenu()
+        self.group_node_cm = QtWidgets.QMenu(self)
+        self.group_node_cm.setObjectName('group_node_cm')
         actions = ['nodeProperties', None, 'nodeNew', 'nodeRename', 'nodeCut',
                    'nodeCopy', 'nodePaste', 'nodeDelete']
         vitables.utils.addActions(self.group_node_cm, actions,
                                   self.gui_actions)
 
-        self.leaf_node_cm = QtWidgets.QMenu()
+        self.leaf_node_cm = QtWidgets.QMenu(self)
+        self.leaf_node_cm.setObjectName('leaf_node_cm')
         actions = ['nodeOpen', 'nodeClose', None, 'nodeProperties', None,
                    'nodeRename', 'nodeCut', 'nodeCopy', 'nodePaste',
                    'nodeDelete', None, 'queryNew']
         vitables.utils.addActions(self.leaf_node_cm, actions, self.gui_actions)
 
-        self.mdi_cm = QtWidgets.QMenu()
+        self.mdi_cm = QtWidgets.QMenu(self)
+        self.mdi_cm.setObjectName('mdi_cm')
         actions = [self.window_menu]
         vitables.utils.addActions(self.mdi_cm, actions, self.gui_actions)
 
@@ -662,16 +678,12 @@ class VTGUI(QtWidgets.QMainWindow):
 
         # Quit
         event.accept()
-        # Explicit deletion is required here as a workaround of a PyQt4
-        # v4.8.2 bug. See <QMainWindow.createPopupMenu bug?> thread in
-        # the PyQt4 mailing list for details
-        del self.toolbars_submenu
         QtWidgets.qApp.quit()
 
     def makeCopy(self):
         """Copy text/leaf depending on which widget has focus.
 
-        This methos disambiguates the ``Ctrl+C`` shortcut. If the console has
+        This method disambiguates the ``Ctrl+C`` shortcut. If the console has
         focus then ``Ctrl+C`` will copy the console selected text. If the
         databases tree view has focus then the selected node (if any) will be
         copied.
@@ -720,10 +732,10 @@ class VTGUI(QtWidgets.QMainWindow):
 
         # The set of actions that can be enabled or disabled
         actions = frozenset(['fileClose', 'fileCloseAll', 'fileSaveAs',
-                            'nodeOpen', 'nodeClose', 'nodeProperties',
-                            'nodeNew', 'nodeRename', 'nodeCut', 'nodeCopy',
-                            'nodePaste', 'nodeDelete',
-                            'queryNew', 'queryDeleteAll'])
+                             'nodeOpen', 'nodeClose', 'nodeProperties',
+                             'nodeNew', 'nodeRename', 'nodeCut', 'nodeCopy',
+                             'nodePaste', 'nodeDelete',
+                             'queryNew', 'queryDeleteAll'])
         enabled = set([])
 
         model_rows = self.dbs_tree_model.rowCount(QtCore.QModelIndex())
@@ -764,14 +776,14 @@ class VTGUI(QtWidgets.QMainWindow):
                     enabled = enabled.union(['nodeNew', 'nodePaste'])
                 elif kind == 'group':
                     enabled = enabled.union(['nodeNew', 'nodeRename',
-                                            'nodeCut', 'nodePaste',
-                                            'nodeDelete'])
+                                             'nodeCut', 'nodePaste',
+                                             'nodeDelete'])
                 elif kind == 'table':
                     enabled = enabled.union(['nodeRename', 'nodeCut',
-                                            'nodeDelete'])
+                                             'nodeDelete'])
                 else:
                     enabled = enabled.union(['nodeRename', 'nodeCut',
-                                            'nodeDelete'])
+                                             'nodeDelete'])
 
             if kind not in ('group', 'root group'):
                 if node.has_view:
@@ -795,7 +807,8 @@ class VTGUI(QtWidgets.QMainWindow):
             index += 1
             (mode, filepath) = item.split('#@#')
             action = QtWidgets.QAction('{0:>2} {1}.'.format(index, filepath),
-                                   self, triggered=self.vtapp.openRecentFile)
+                                       self,
+                                       triggered=self.vtapp.openRecentFile)
             action.setData(item)
             if mode == 'r':
                 action.setIcon(iconset['file_ro'])
